# coding: utf-8

"""
    JupyterHub

    The REST API for JupyterHub

    The version of the OpenAPI document: 4.0.2
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from typing import Any, ClassVar, Dict, List, Optional
from pydantic import BaseModel, StrictBool, StrictStr, field_validator
from pydantic import Field
from openapi_client.models.server import Server
try:
    from typing import Self
except ImportError:
    from typing_extensions import Self

class User(BaseModel):
    """
    User
    """ # noqa: E501
    name: Optional[StrictStr] = Field(default=None, description="The user's name")
    admin: Optional[StrictBool] = Field(default=None, description="Whether the user is an admin")
    roles: Optional[List[StrictStr]] = Field(default=None, description="The names of roles this user has")
    groups: Optional[List[StrictStr]] = Field(default=None, description="The names of groups where this user is a member")
    server: Optional[StrictStr] = Field(default=None, description="The user's notebook server's base URL, if running; null if not.")
    pending: Optional[StrictStr] = Field(default=None, description="The currently pending action, if any")
    last_activity: Optional[datetime] = Field(default=None, description="Timestamp of last-seen activity from the user")
    servers: Optional[Dict[str, Server]] = Field(default=None, description="The servers for this user. By default: only includes _active_ servers. Changed in 3.0: if `?include_stopped_servers` parameter is specified, stopped servers will be included as well. ")
    auth_state: Optional[Dict[str, Any]] = Field(default=None, description="Authentication state of the user. Only available with admin:users:auth_state scope. None otherwise. ")
    __properties: ClassVar[List[str]] = ["name", "admin", "roles", "groups", "server", "pending", "last_activity", "servers", "auth_state"]

    @field_validator('pending')
    def pending_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in ('spawn', 'stop'):
            raise ValueError("must be one of enum values ('spawn', 'stop')")
        return value

    model_config = {
        "populate_by_name": True,
        "validate_assignment": True,
        "protected_namespaces": (),
    }


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of User from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        _dict = self.model_dump(
            by_alias=True,
            exclude={
            },
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each value in servers (dict)
        _field_dict = {}
        if self.servers:
            for _key in self.servers:
                if self.servers[_key]:
                    _field_dict[_key] = self.servers[_key].to_dict()
            _dict['servers'] = _field_dict
        return _dict

    @classmethod
    def from_dict(cls, obj: Dict) -> Self:
        """Create an instance of User from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "name": obj.get("name"),
            "admin": obj.get("admin"),
            "roles": obj.get("roles"),
            "groups": obj.get("groups"),
            "server": obj.get("server"),
            "pending": obj.get("pending"),
            "last_activity": obj.get("last_activity"),
            "servers": dict(
                (_k, Server.from_dict(_v))
                for _k, _v in obj.get("servers").items()
            )
            if obj.get("servers") is not None
            else None,
            "auth_state": obj.get("auth_state")
        })
        return _obj





# coding: utf-8

"""
    JupyterHub

    The REST API for JupyterHub

    The version of the OpenAPI document: 4.0.2
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from openapi_client.api.default_api import DefaultApi


class TestDefaultApi(unittest.TestCase):
    """DefaultApi unit test stubs"""

    def setUp(self) -> None:
        self.api = DefaultApi()

    def tearDown(self) -> None:
        pass

    def test_authorizations_cookie_cookie_name_cookie_value_get(self) -> None:
        """Test case for authorizations_cookie_cookie_name_cookie_value_get

        Identify a user from a cookie
        """
        pass

    def test_authorizations_token_post(self) -> None:
        """Test case for authorizations_token_post

        Request a new API token
        """
        pass

    def test_authorizations_token_token_get(self) -> None:
        """Test case for authorizations_token_token_get

        Identify a user or service from an API token
        """
        pass

    def test_groups_get(self) -> None:
        """Test case for groups_get

        List groups
        """
        pass

    def test_groups_name_delete(self) -> None:
        """Test case for groups_name_delete

        Delete a group
        """
        pass

    def test_groups_name_get(self) -> None:
        """Test case for groups_name_get

        Get a group by name
        """
        pass

    def test_groups_name_post(self) -> None:
        """Test case for groups_name_post

        Create a group
        """
        pass

    def test_groups_name_properties_put(self) -> None:
        """Test case for groups_name_properties_put

        Set the group properties.  Added in JupyterHub 3.2. 
        """
        pass

    def test_groups_name_users_delete(self) -> None:
        """Test case for groups_name_users_delete

        Remove users from a group 
        """
        pass

    def test_groups_name_users_post(self) -> None:
        """Test case for groups_name_users_post

        Add users to a group
        """
        pass

    def test_info_get(self) -> None:
        """Test case for info_get

        Get detailed info about JupyterHub
        """
        pass

    def test_oauth2_authorize_get(self) -> None:
        """Test case for oauth2_authorize_get

        OAuth 2.0 authorize endpoint
        """
        pass

    def test_oauth2_token_post(self) -> None:
        """Test case for oauth2_token_post

        Request an OAuth2 token
        """
        pass

    def test_proxy_get(self) -> None:
        """Test case for proxy_get

        Get the proxy's routing table
        """
        pass

    def test_proxy_patch(self) -> None:
        """Test case for proxy_patch

        Notify the Hub about a new proxy
        """
        pass

    def test_proxy_post(self) -> None:
        """Test case for proxy_post

        Force the Hub to sync with the proxy
        """
        pass

    def test_root_get(self) -> None:
        """Test case for root_get

        Get JupyterHub version
        """
        pass

    def test_services_get(self) -> None:
        """Test case for services_get

        List services
        """
        pass

    def test_services_name_get(self) -> None:
        """Test case for services_name_get

        Get a service by name
        """
        pass

    def test_shutdown_post(self) -> None:
        """Test case for shutdown_post

        Shutdown the Hub
        """
        pass

    def test_user_get(self) -> None:
        """Test case for user_get

        Return authenticated user's model
        """
        pass

    def test_users_get(self) -> None:
        """Test case for users_get

        List users
        """
        pass

    def test_users_name_activity_post(self) -> None:
        """Test case for users_name_activity_post

        Notify Hub of activity for a given user.
        """
        pass

    def test_users_name_delete(self) -> None:
        """Test case for users_name_delete

        Delete a user
        """
        pass

    def test_users_name_get(self) -> None:
        """Test case for users_name_get

        Get a user by name
        """
        pass

    def test_users_name_patch(self) -> None:
        """Test case for users_name_patch

        Modify a user
        """
        pass

    def test_users_name_post(self) -> None:
        """Test case for users_name_post

        Create a single user
        """
        pass

    def test_users_name_server_delete(self) -> None:
        """Test case for users_name_server_delete

        Stop a user's server
        """
        pass

    def test_users_name_server_post(self) -> None:
        """Test case for users_name_server_post

        Start a user's single-user notebook server
        """
        pass

    def test_users_name_servers_server_name_delete(self) -> None:
        """Test case for users_name_servers_server_name_delete

        Stop a user's named server
        """
        pass

    def test_users_name_servers_server_name_post(self) -> None:
        """Test case for users_name_servers_server_name_post

        Start a user's single-user named-server notebook server
        """
        pass

    def test_users_name_tokens_get(self) -> None:
        """Test case for users_name_tokens_get

        List tokens for the user
        """
        pass

    def test_users_name_tokens_post(self) -> None:
        """Test case for users_name_tokens_post

        Create a new token for the user
        """
        pass

    def test_users_name_tokens_token_id_delete(self) -> None:
        """Test case for users_name_tokens_token_id_delete

        Delete (revoke) a token by id
        """
        pass

    def test_users_name_tokens_token_id_get(self) -> None:
        """Test case for users_name_tokens_token_id_get

        Get the model for a token by id
        """
        pass

    def test_users_post(self) -> None:
        """Test case for users_post

        Create multiple users
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    JupyterHub

    The REST API for JupyterHub

    The version of the OpenAPI document: 4.0.2
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from typing import Any, ClassVar, Dict, List, Optional
from pydantic import BaseModel, StrictBool, StrictStr, field_validator
from pydantic import Field
try:
    from typing import Self
except ImportError:
    from typing_extensions import Self

class Server(BaseModel):
    """
    Server
    """ # noqa: E501
    name: Optional[StrictStr] = Field(default=None, description="The server's name. The user's default server has an empty name ('')")
    ready: Optional[StrictBool] = Field(default=None, description="Whether the server is ready for traffic. Will always be false when any transition is pending. ")
    stopped: Optional[StrictBool] = Field(default=None, description="Whether the server is stopped. Added in JupyterHub 3.0, and only useful when using the `?include_stopped_servers` request parameter. Now that stopped servers may be included (since JupyterHub 3.0), this is the simplest way to select stopped servers. Always equivalent to `not (ready or pending)`. ")
    pending: Optional[StrictStr] = Field(default=None, description="The currently pending action, if any. A server is not ready if an action is pending. ")
    url: Optional[StrictStr] = Field(default=None, description="The URL where the server can be accessed (typically /user/:name/:server.name/). ")
    progress_url: Optional[StrictStr] = Field(default=None, description="The URL for an event-stream to retrieve events during a spawn. ")
    started: Optional[datetime] = Field(default=None, description="UTC timestamp when the server was last started.")
    last_activity: Optional[datetime] = Field(default=None, description="UTC timestamp last-seen activity on this server.")
    state: Optional[Dict[str, Any]] = Field(default=None, description="Arbitrary internal state from this server's spawner. Only available on the hub's users list or get-user-by-name method, and only with admin:users:server_state scope. None otherwise.")
    user_options: Optional[Dict[str, Any]] = Field(default=None, description="User specified options for the user's spawned instance of a single-user server.")
    __properties: ClassVar[List[str]] = ["name", "ready", "stopped", "pending", "url", "progress_url", "started", "last_activity", "state", "user_options"]

    @field_validator('pending')
    def pending_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in ('spawn', 'stop'):
            raise ValueError("must be one of enum values ('spawn', 'stop')")
        return value

    model_config = {
        "populate_by_name": True,
        "validate_assignment": True,
        "protected_namespaces": (),
    }


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of Server from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        _dict = self.model_dump(
            by_alias=True,
            exclude={
            },
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Dict) -> Self:
        """Create an instance of Server from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "name": obj.get("name"),
            "ready": obj.get("ready"),
            "stopped": obj.get("stopped"),
            "pending": obj.get("pending"),
            "url": obj.get("url"),
            "progress_url": obj.get("progress_url"),
            "started": obj.get("started"),
            "last_activity": obj.get("last_activity"),
            "state": obj.get("state"),
            "user_options": obj.get("user_options")
        })
        return _obj





# coding: utf-8

"""
    JupyterHub

    The REST API for JupyterHub

    The version of the OpenAPI document: 4.0.2
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from openapi_client.models.users_name_activity_post_request import UsersNameActivityPostRequest

class TestUsersNameActivityPostRequest(unittest.TestCase):
    """UsersNameActivityPostRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> UsersNameActivityPostRequest:
        """Test UsersNameActivityPostRequest
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `UsersNameActivityPostRequest`
        """
        model = UsersNameActivityPostRequest()
        if include_optional:
            return UsersNameActivityPostRequest(
                last_activity = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                servers = openapi_client.models._users__name__activity_post_request_servers._users__name__activity_post_request_servers(
                    <server_name> = openapi_client.models._users__name__activity_post_request_servers__server_name_._users__name__activity_post_request_servers__server_name_(
                        last_activity = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), )
            )
        else:
            return UsersNameActivityPostRequest(
        )
        """

    def testUsersNameActivityPostRequest(self):
        """Test UsersNameActivityPostRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
